from PyObjCTools.TestSupport import TestCase


import CoreSpotlight


class TestCSSearchQuery(TestCase):
    def testConstants(self):
        self.assertEqual(CoreSpotlight.CSSearchQueryErrorCodeUnknown, -2000)
        self.assertEqual(CoreSpotlight.CSSearchQueryErrorCodeIndexUnreachable, -2001)
        self.assertEqual(CoreSpotlight.CSSearchQueryErrorCodeInvalidQuery, -2002)
        self.assertEqual(CoreSpotlight.CSSearchQueryErrorCodeCancelled, -2003)

        self.assertIsInstance(CoreSpotlight.CSSearchQueryErrorDomain, str)

    def testMethods(self):
        self.assertResultIsBOOL(CoreSpotlight.CSSearchQuery.isCancelled)
        self.assertResultIsBlock(CoreSpotlight.CSSearchQuery.foundItemsHandler, b"v@")
        self.assertArgIsBlock(
            CoreSpotlight.CSSearchQuery.setFoundItemsHandler_, 0, b"v@"
        )
        self.assertResultIsBlock(CoreSpotlight.CSSearchQuery.completionHandler, b"v@")
        self.assertArgIsBlock(
            CoreSpotlight.CSSearchQuery.setCompletionHandler_, 0, b"v@"
        )



"""
Python mapping for the CoreSpotlight framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from CoreSpotlight import _metadata
from CoreSpotlight import _CoreSpotlight

sys.modules["CoreSpotlight"] = mod = objc.ObjCLazyModule(
    "CoreSpotlight",
    "com.apple.CoreSpotlight",
    objc.pathForFramework("/System/Library/Frameworks/CoreSpotlight.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_CoreSpotlight, Foundation),
)


del sys.modules["CoreSpotlight._metadata"]



# This file is generated by objective.metadata
#
# Last update: Sat Jun 27 18:37:34 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$CSIndexErrorDomain$CSMailboxArchive$CSMailboxDrafts$CSMailboxInbox$CSMailboxJunk$CSMailboxSent$CSMailboxTrash$CSQueryContinuationActionType$CSSearchQueryErrorDomain$CSSearchQueryString$CSSearchableItemActionType$CSSearchableItemActivityIdentifier$CoreSpotlightVersionNumber@d$CoreSpotlightVersionString@*$"""
enums = """$CSIndexErrorCodeIndexUnavailableError@-1000$CSIndexErrorCodeIndexingUnsupported@-1005$CSIndexErrorCodeInvalidClientStateError@-1002$CSIndexErrorCodeInvalidItemError@-1001$CSIndexErrorCodeQuotaExceeded@-1004$CSIndexErrorCodeRemoteConnectionError@-1003$CSIndexErrorCodeUnknownError@-1$CSSearchQueryErrorCodeCancelled@-2003$CSSearchQueryErrorCodeIndexUnreachable@-2001$CSSearchQueryErrorCodeInvalidQuery@-2002$CSSearchQueryErrorCodeUnknown@-2000$CoreSpotlightAPIVersion@40$"""
misc.update({})
aliases = {"CS_TVOS_UNAVAILABLE": "__TVOS_PROHIBITED"}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"CSCustomAttributeKey",
        b"initWithKeyName:searchable:searchableByDefault:unique:multiValued:",
        {
            "arguments": {
                3: {"type": "Z"},
                4: {"type": "Z"},
                5: {"type": "Z"},
                6: {"type": "Z"},
            }
        },
    )
    r(b"CSCustomAttributeKey", b"isMultiValued", {"retval": {"type": "Z"}})
    r(b"CSCustomAttributeKey", b"isSearchable", {"retval": {"type": "Z"}})
    r(b"CSCustomAttributeKey", b"isSearchableByDefault", {"retval": {"type": "Z"}})
    r(b"CSCustomAttributeKey", b"isUnique", {"retval": {"type": "Z"}})
    r(b"CSCustomAttributeKey", b"setMultiValued:", {"arguments": {2: {"type": "Z"}}})
    r(b"CSCustomAttributeKey", b"setSearchable:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"CSCustomAttributeKey",
        b"setSearchableByDefault:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(b"CSCustomAttributeKey", b"setUnique:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"CSSearchQuery",
        b"completionHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                }
            }
        },
    )
    r(
        b"CSSearchQuery",
        b"foundItemsHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                }
            }
        },
    )
    r(b"CSSearchQuery", b"isCancelled", {"retval": {"type": "Z"}})
    r(
        b"CSSearchQuery",
        b"setCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CSSearchQuery",
        b"setFoundItemsHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CSSearchableIndex",
        b"deleteAllSearchableItemsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CSSearchableIndex",
        b"deleteSearchableItemsWithDomainIdentifiers:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CSSearchableIndex",
        b"deleteSearchableItemsWithIdentifiers:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CSSearchableIndex",
        b"endIndexBatchWithClientState:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CSSearchableIndex",
        b"fetchLastClientStateWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"CSSearchableIndex",
        b"indexSearchableItems:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(b"CSSearchableIndex", b"isIndexingAvailable", {"retval": {"type": b"Z"}})
    r(
        b"NSObject",
        b"dataForSearchableIndex:itemIdentifier:typeIdentifier:error:",
        {
            "required": False,
            "retval": {"type": b"@"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": "^@", "type_modifier": b"o"},
            },
        },
    )
    r(
        b"NSObject",
        b"fileURLForSearchableIndex:itemIdentifier:typeIdentifier:inPlace:error:",
        {
            "required": False,
            "retval": {"type": b"@"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": "Z"},
                6: {"type": "^@", "type_modifier": b"o"},
            },
        },
    )
    r(
        b"NSObject",
        b"searchableIndex:reindexAllSearchableItemsWithAcknowledgementHandler:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    },
                    "type": "@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"searchableIndex:reindexSearchableItemsWithIdentifiers:acknowledgementHandler:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    },
                    "type": "@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"searchableIndexDidFinishThrottle:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"searchableIndexDidThrottle:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase


import CoreSpotlight


class TestCSSearchableItemAttributeSet(TestCase):
    def testMethods(self):
        self.assertArgIsBOOL(
            CoreSpotlight.CSCustomAttributeKey.initWithKeyName_searchable_searchableByDefault_unique_multiValued_,
            1,
        )
        self.assertArgIsBOOL(
            CoreSpotlight.CSCustomAttributeKey.initWithKeyName_searchable_searchableByDefault_unique_multiValued_,
            2,
        )
        self.assertArgIsBOOL(
            CoreSpotlight.CSCustomAttributeKey.initWithKeyName_searchable_searchableByDefault_unique_multiValued_,
            3,
        )
        self.assertArgIsBOOL(
            CoreSpotlight.CSCustomAttributeKey.initWithKeyName_searchable_searchableByDefault_unique_multiValued_,
            4,
        )

        self.assertArgIsBOOL(CoreSpotlight.CSCustomAttributeKey.setSearchable_, 0)
        self.assertArgIsBOOL(
            CoreSpotlight.CSCustomAttributeKey.setSearchableByDefault_, 0
        )
        self.assertArgIsBOOL(CoreSpotlight.CSCustomAttributeKey.setUnique_, 0)
        self.assertArgIsBOOL(CoreSpotlight.CSCustomAttributeKey.setMultiValued_, 0)

        self.assertResultIsBOOL(CoreSpotlight.CSCustomAttributeKey.isSearchable)
        self.assertResultIsBOOL(
            CoreSpotlight.CSCustomAttributeKey.isSearchableByDefault
        )
        self.assertResultIsBOOL(CoreSpotlight.CSCustomAttributeKey.isUnique)
        self.assertResultIsBOOL(CoreSpotlight.CSCustomAttributeKey.isMultiValued)
